@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Adapted version of the Git::NextVersion plugin to allow influencing version bumping.
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 #pod =head1 DESCRIPTION
 #pod
@@ -171,7 +171,7 @@ Dist::Zilla::Plugin::Author::HAYOBAAN::NextVersion - Adapted version of the Git:
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 DESCRIPTION
 
@@ -255,7 +255,7 @@ The original L<Git::NextVersion|Dist::Zilla::Plugin::Git::NextVersion> plugin.
 
 =head1 AUTHOR
 
-Hayo Baan <info@hayobaan.com>
+Hayo Baan <hayobaan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
