@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Hayo Baan's Dist::Zilla configuration
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 #pod =head1 DESCRIPTION
 #pod
@@ -910,7 +910,7 @@ Dist::Zilla::PluginBundle::Author::HAYOBAAN - Hayo Baan's Dist::Zilla configurat
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 DESCRIPTION
 
@@ -1555,7 +1555,7 @@ Mike Doherty L<DOHERTY|Dist::Zilla::PluginBundle::Author::DOHERTY>
 
 =head1 AUTHOR
 
-Hayo Baan <info@hayobaan.com>
+Hayo Baan <hayobaan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
